/*= R&S SGU Signal Generator Include File ===================================*/
/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/

#ifndef __RSSGU_HEADER
#define __RSSGU_HEADER

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

#include "visaabstraction.h"
  /*****************************************************************************/
  /*= Instrument Driver Specific Error/Warning Codes ==========================*/
  /*****************************************************************************/
#define VI_WARN_NSUP_ID_QUERY     (          0x3FFC0101L)
#define VI_WARN_NSUP_RESET        (          0x3FFC0102L)
#define VI_WARN_NSUP_SELF_TEST    (          0x3FFC0103L)
#define VI_WARN_NSUP_ERROR_QUERY  (          0x3FFC0104L)
#define VI_WARN_NSUP_REV_QUERY    (          0x3FFC0105L)

#define VI_ERROR_PARAMETER1       (_VI_ERROR+0x3FFC0001L)
#define VI_ERROR_PARAMETER2       (_VI_ERROR+0x3FFC0002L)
#define VI_ERROR_PARAMETER3       (_VI_ERROR+0x3FFC0003L)
#define VI_ERROR_PARAMETER4       (_VI_ERROR+0x3FFC0004L)
#define VI_ERROR_PARAMETER5       (_VI_ERROR+0x3FFC0005L)
#define VI_ERROR_PARAMETER6       (_VI_ERROR+0x3FFC0006L)
#define VI_ERROR_PARAMETER7       (_VI_ERROR+0x3FFC0007L)
#define VI_ERROR_PARAMETER8       (_VI_ERROR+0x3FFC0008L)
#define VI_ERROR_FAIL_ID_QUERY    (_VI_ERROR+0x3FFC0011L)
#define VI_ERROR_INV_RESPONSE     (_VI_ERROR+0x3FFC0012L)

#define VI_ERROR_INSTR_FILE_OPEN                    (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE                   (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE        (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER8                   (_VI_ERROR+0x3FFC0808L)
#define VI_ERROR_INSTR_PARAMETER9                   (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10                  (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11                  (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12                  (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13                  (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14                  (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15                  (_VI_ERROR+0x3FFC080FL)

  /*****************************************************************************/
  /*= Define Instrument Specific Error/Warning Codes Here =====================*/
  /*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                          (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                       (_VI_ERROR+0x3FFC0900L)

#define RSSGU_ERROR_INSTRUMENT_ERROR                (VI_ERROR_INSTR_OFFSET + 0xF0L)
  /* Add instrument driver specific error codes here */

#define RSSGU_ERROR_INVALID_CONFIGURATION           (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSSGU_ERROR_INSTRUMENT_OPTION               (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSSGU_ERROR_INSTRUMENT_NSUP_MODEL           (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define RSSGU_ERROR_SETTINGS_CONFLICT               (VI_ERROR_INSTR_OFFSET + 0xF4L)
#define RSSGU_ERROR_CALIBRATION_FAILED              (VI_ERROR_INSTR_OFFSET + 0xF5L)
#define RSSGU_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE   (VI_ERROR_INSTR_OFFSET + 0xF6L)
  /* Add instrument driver specific warning codes here */
#define RSSGU_WARNING_SMALL_BUFFER                  (VI_WARNING_INSTR_OFFSET + 0xF1L)


  /*****************************************************************************/
  /*= Instrument specific defines =============================================*/
  /*****************************************************************************/

#define RSSGU_SOURCE_INT    0
#define RSSGU_SOURCE_EXT    1


#define RSSGU_LEVEL_MODE_AUTO 0
#define RSSGU_LEVEL_MODE_LNO  1
#define RSSGU_LEVEL_MODE_LDIS 2

#define RSSGU_LEVEL_SETT_CHARACT_AUTO 0
#define RSSGU_LEVEL_SETT_CHARACT_UNIN 1
#define RSSGU_LEVEL_SETT_CHARACT_MON  2
#define RSSGU_LEVEL_SETT_CHARACT_CWSW 3
#define RSSGU_LEVEL_SETT_CHARACT_USER 4	

#define RSSGU_LEVEL_POW_ON_OFF  0
#define RSSGU_LEVEL_POW_ON_UNCH 1

#define RSSGU_LEVEL_ALC_STATE_ONT  0
#define RSSGU_LEVEL_ALC_STATE_ON   1
#define RSSGU_LEVEL_ALC_STATE_OFFT 2

#define RSSGU_LEVEL_ALC_DETECTOR_AUTO 0
#define RSSGU_LEVEL_ALC_DETECTOR_LOW  1
#define RSSGU_LEVEL_ALC_DETECTOR_MED  2
#define RSSGU_LEVEL_ALC_DETECTOR_HIGH 3

#define RSSGU_SGU_HW_CHANN_LAN  0
#define RSSGU_SGU_HW_CHANN_USB  1
#define RSSGU_SGU_HW_CHANN_PCIE 2
#define RSSGU_SGU_HW_CHANN_SOCK 3

#define RSSGU_REMOTE_OPER_MODE_EXT 0
#define RSSGU_REMOTE_OPER_MODE_STD 1

#define RSSGU_SYSTEM_INCOMPLETE 0
#define RSSGU_SYSTEM_COMPLETE   1

#define RSSGU_UNIT_ANGLE_DEG 0
#define RSSGU_UNIT_ANGLE_RAD 1

#define RSSGU_UNIT_POWER_V   0
#define RSSGU_UNIT_POWER_DBM 1

#define RSSGU_UNIT_VELOCITY_MPS 0
#define RSSGU_UNIT_VELOCITY_KMH 1
#define RSSGU_UNIT_VELOCITY_MPH 2

#define RSSGU_IP_ADDRESS_MODE_AUTO 0
#define RSSGU_IP_ADDRESS_MODE_STAT 1

#define RSSGU_TEST_COMMAND_SSYN       0
#define RSSGU_TEST_COMMAND_SSYNEX     1
#define RSSGU_TEST_COMMAND_IQOP3      2
#define RSSGU_TEST_COMMAND_IQOP6      3
#define RSSGU_TEST_COMMAND_SATT3      4
#define RSSGU_TEST_COMMAND_SATT6      5
#define RSSGU_TEST_COMMAND_BBINS      6
#define RSSGU_TEST_COMMAND_DIRECTLAST 7

#define RSSGU_HCOPY_AUTO_FILE_DAY    0
#define RSSGU_HCOPY_AUTO_FILE_MONTH  1
#define RSSGU_HCOPY_AUTO_FILE_YEAR   2


#define RSSGU_LEVEL_ATT_ON_FIX 0
#define RSSGU_LEVEL_ATT_ON_MAX 1    

#define RSSGU_FORMAT_DATA_ASCII 0
#define RSSGU_FORMAT_DATA_PACK  1

#define RSSGU_REGISTER_OPERATION    0
#define RSSGU_REGISTER_QUESTIONABLE 1

#define RSSGU_REGISTER_COND   0
#define RSSGU_REGISTER_EVENT  1
#define RSSGU_REGISTER_ENABLE 2
#define RSSGU_REGISTER_NTR    3
#define RSSGU_REGISTER_PTR    4

#define RSSGU_TERMINATOR_MODE_EOI  0
#define RSSGU_TERMINATOR_MODE_STAN 1    

#define RSSGU_RF_ATT_MODE_AUTO 0
#define RSSGU_RF_ATT_MODE_FIX  1

#define  RSSGU_TRG_CON_OP_MODE_IN             0         
#define  RSSGU_TRG_CON_OP_MODE_LO             1      
#define  RSSGU_TRG_CON_OP_MODE_MEASLATENCY    2
#define  RSSGU_TRG_CON_OP_MODE_MEASMSGARRIVED 3
#define  RSSGU_TRG_CON_OP_MODE_HI             4
#define  RSSGU_TRG_CON_OP_MODE_FBFAULT        5
#define  RSSGU_TRG_CON_OP_MODE_SIGNALVALID    6
#define  RSSGU_TRG_CON_OP_MODE_EXTOUT1        7
#define  RSSGU_TRG_CON_OP_MODE_EXTOUT2        8
#define  RSSGU_TRG_CON_OP_MODE_BLANK          9
#define  RSSGU_TRG_CON_OP_MODE_SIGNALNVALID   10
#define  RSSGU_TRG_CON_OP_MODE_PULMEXT        11



#define RSSGU_DIAG_MMAC_BAR_SCOM 0
#define RSSGU_DIAG_MMAC_BAR_IQUPCON20   1

#define RSSGU_VAL_ASSEMBLY_INDEX_COMMON     0
#define RSSGU_VAL_ASSEMBLY_INDEX_RF	      	1

#define RSSGU_VAL_OPTION_INDEX_HARDWARE		0
#define RSSGU_VAL_OPTION_INDEX_SOFTWARE		1

#define RSSGU_ECO_MODE_OFF 0
#define RSSGU_ECO_MODE_EM1 1	

#define RSSGU_PULSE_POL_NORM 0
#define RSSGU_PULSE_POL_INV 1
	
#define RSSGU_CAL_RESULT_0		0
#define RSSGU_CAL_RESULT_1 		1
#define RSSGU_CAL_RESULT_RUNN   2
#define RSSGU_CAL_RESULT_STOP   3


/* --- Serial Baud Rate ----------------------------------------------- */     
#define RSSGU_SERIAL_BAUDRATE_2400                          0
#define RSSGU_SERIAL_BAUDRATE_4800                          1
#define RSSGU_SERIAL_BAUDRATE_9600                          2
#define RSSGU_SERIAL_BAUDRATE_19200                         3
#define RSSGU_SERIAL_BAUDRATE_38400                         4
#define RSSGU_SERIAL_BAUDRATE_57600                         5
#define RSSGU_SERIAL_BAUDRATE_115200                        6

/* --- Serial Parity ----------------------------------------------- */     
#define RSSGU_SERIAL_PARITY_NONE                            0
#define RSSGU_SERIAL_PARITY_ODD                             1
#define RSSGU_SERIAL_PARITY_EVEN                            2

/* --- Serial Stop Bits ----------------------------------------------- */     
#define RSSGU_SERIAL_STOPBITS_1                             0
#define RSSGU_SERIAL_STOPBITS_2                             1



  ViStatus _VI_FUNC rssgu_init (ViRsrc resourceName, ViBoolean IDQuery,
    ViBoolean resetDevice, ViSession* instrumentHandle);
  ViStatus _VI_FUNC rssgu_SetFrequencyAndLevel (ViSession instrumentHandle,
    ViReal64 frequency, ViReal64 level);
  ViStatus _VI_FUNC rssgu_UseFastSettings (ViSession instrumentHandle,
    ViBoolean fastEnabled,
    ViBoolean asynchronousEnabled);
  ViStatus _VI_FUNC rssgu_GetFastSettings (ViSession instrumentHandle,
    ViPBoolean enableFast, 
    ViPBoolean enableAsynchronous);
  ViStatus _VI_FUNC rssgu_FastSync (ViSession instrumentHandle);
  ViStatus _VI_FUNC rssgu_SetRFState (ViSession instrumentHandle, ViBoolean state);
  ViStatus _VI_FUNC rssgu_GetRFState (ViSession instrumentHandle, ViBoolean* state);
  ViStatus _VI_FUNC rssgu_GetRFNumberofPaths (ViSession instrumentHandle, ViInt32 *paths);

  ViStatus _VI_FUNC rssgu_SetRFAttenuatorMode (ViSession instrumentHandle,
    ViInt32 attenuatorMode);
  ViStatus _VI_FUNC rssgu_GetRFAttenuatorMode (ViSession instrumentHandle,
    ViInt32* attenuatorMode);
ViStatus _VI_FUNC rssgu_SetFrequency (ViSession instrumentHandle, ViReal64 frequency);
ViStatus _VI_FUNC rssgu_GetFrequency (ViSession instrumentHandle, ViReal64 *frequency);

ViStatus _VI_FUNC rssgu_GetLoscFrequency (ViSession instrumentHandle, ViReal64 *frequency);

  ViStatus _VI_FUNC rssgu_GetLoscLevel (ViSession instrumentHandle,
    ViReal64* level);

  ViStatus _VI_FUNC rssgu_SetLevel (ViSession instrumentHandle, ViReal64 level);
  ViStatus _VI_FUNC rssgu_ConfigureLevelSettings (ViSession instrumentHandle,
    ViInt32 mode,
    ViInt32 settingCharacteristic,
    ViReal64 limit);
  ViStatus _VI_FUNC rssgu_SetLevelMode (ViSession instrumentHandle, ViInt32 mode);
  ViStatus _VI_FUNC rssgu_GetLevelMode (ViSession instrumentHandle, ViInt32* mode);
  ViStatus _VI_FUNC rssgu_SetLevelSettingCharacteristic (ViSession instrumentHandle,
    ViInt32 settingCharacteristic);
  ViStatus _VI_FUNC rssgu_GetLevelSettingCharacteristic (ViSession instrumentHandle,
    ViInt32* settingCharacteristic);
  ViStatus _VI_FUNC rssgu_GetLevel (ViSession instrumentHandle, ViReal64* level);

  ViStatus _VI_FUNC rssgu_GetPeakEnvelopePower (ViSession instrumentHandle,
    ViReal64 *PEP);

  ViStatus _VI_FUNC rssgu_GetLevelLowerRange (ViSession instrumentHandle,
    ViReal64 *LowerLimit);

  ViStatus _VI_FUNC rssgu_GetLevelUpperRange (ViSession instrumentHandle,
    ViReal64 *UpperLimit);


  ViStatus _VI_FUNC rssgu_SetLevelLimit (ViSession instrumentHandle, ViReal64 limit);
  ViStatus _VI_FUNC rssgu_GetLevelLimit (ViSession instrumentHandle, ViReal64* limit);
  ViStatus _VI_FUNC rssgu_SetLevelPowerOnState (ViSession instrumentHandle,
    ViInt32 powerOnState);
  ViStatus _VI_FUNC rssgu_GetLevelPowerOnState (ViSession instrumentHandle,
    ViInt32* powerOnState);
  ViStatus _VI_FUNC rssgu_SetLevelALCState (ViSession instrumentHandle,
    ViInt32 state);
  ViStatus _VI_FUNC rssgu_GetLevelALCState (ViSession instrumentHandle,
    ViInt32* state);
  ViStatus _VI_FUNC rssgu_ReadjustLevelALC (ViSession instrumentHandle);
  ViStatus _VI_FUNC rssgu_SetAttenuatorModeAfterOn (ViSession instrumentHandle,
    ViInt32 mode);
  ViStatus _VI_FUNC rssgu_GetAttenuatorModeAfterOn (ViSession instrumentHandle,
    ViInt32* mode);
  ViStatus _VI_FUNC rssgu_SetAttenuatorSwitchOverOffset (ViSession instrumentHandle,
    ViReal64 offset);
  ViStatus _VI_FUNC rssgu_GetAttenuatorSwitchOverOffset (ViSession instrumentHandle,
    ViReal64* offset);
  ViStatus _VI_FUNC rssgu_GetAttenuatorLowerRange (ViSession instrumentHandle,
    ViReal64* attenuatorLowerRange);
  ViStatus _VI_FUNC rssgu_GetAttenuatorUpperRange (ViSession instrumentHandle,
    ViReal64* attenuatorUpperRange);
  ViStatus _VI_FUNC rssgu_ConfigureIQImpairments (ViSession instrumentHandle,
    ViBoolean state, ViReal64 iOffset,
    ViReal64 qOffset,
    ViReal64 gainImbalance,
    ViReal64 quadratureOffset);
  ViStatus _VI_FUNC rssgu_SetIQModulatorState (ViSession instrumentHandle,
    ViBoolean IQModulatorState);
  ViStatus _VI_FUNC rssgu_GetIQModulatorState (ViSession instrumentHandle,
    ViBoolean* IQModulatorState);
  ViStatus _VI_FUNC rssgu_SetIQImpairmentsState (ViSession instrumentHandle,
    ViBoolean state);
  ViStatus _VI_FUNC rssgu_GetIQImpairmentsState (ViSession instrumentHandle,
    ViBoolean* state);
  ViStatus _VI_FUNC rssgu_SetIQImpairmentsIOffset (ViSession instrumentHandle,
    ViReal64 iOffset);
  ViStatus _VI_FUNC rssgu_GetIQImpairmentsIOffset (ViSession instrumentHandle,
    ViReal64* iOffset);
  ViStatus _VI_FUNC rssgu_SetIQImpairmentsQOffset (ViSession instrumentHandle,
    ViReal64 qOffset);
  ViStatus _VI_FUNC rssgu_GetIQImpairmentsQOffset (ViSession instrumentHandle,
    ViReal64* qOffset);
  ViStatus _VI_FUNC rssgu_SetIQImpairmentsGainImbalance (ViSession instrumentHandle,
    ViReal64 gainImbalance);
  ViStatus _VI_FUNC rssgu_GetIQImpairmentsGainImbalance (ViSession instrumentHandle,
    ViReal64* gainImbalance);
  ViStatus _VI_FUNC rssgu_SetIQImpairmentsQuadratureOffset (ViSession instrumentHandle,
    ViReal64 quadratureOffset);
  ViStatus _VI_FUNC rssgu_GetIQImpairmentsQuadratureOffset (ViSession instrumentHandle,
    ViReal64* quadratureOffset);

  ViStatus _VI_FUNC rssgu_SetIQCrestFactor (ViSession instrumentHandle,
    ViReal64 crestFactor);

  ViStatus _VI_FUNC rssgu_GetIQCrestFactor (ViSession instrumentHandle,
    ViReal64 *crestFactor);

  ViStatus _VI_FUNC rssgu_SetPulseModulatorState (ViSession instrSession,
    ViBoolean state);

  ViStatus _VI_FUNC rssgu_GetPulseModulatorState (ViSession instrSession,
    ViBoolean *state);

  ViStatus _VI_FUNC rssgu_SetPulseModulatorPolarity (ViSession instrSession,
    ViInt32 polarity);

  ViStatus _VI_FUNC rssgu_GetPulseModulatorPolarity (ViSession instrSession,
    ViInt32 *polarity);


  ViStatus _VI_FUNC rssgu_LockInstrument (ViSession instrumentHandle, ViInt32 lockID,
    ViInt32* result);
  ViStatus _VI_FUNC rssgu_UnlockInstrument (ViSession instrumentHandle,
    ViInt32 lockID);
  ViStatus _VI_FUNC rssgu_CALibrationLevelStart (ViSession instrumentHandle);
    
  ViStatus _VI_FUNC rssgu_CALibrationLevelResult (ViSession instrumentHandle,
    ViInt32* result);

  ViStatus _VI_FUNC rssgu_CALibrationIQModulatorStart (ViSession instrumentHandle);    
  ViStatus _VI_FUNC rssgu_CALibrationIQModulatorResult (ViSession instrumentHandle,
                                                  ViInt32* result);

  ViStatus _VI_FUNC rssgu_CALibrationIQModulatorForCurrentFrequencyStart
    (ViSession instrumentHandle); 
  ViStatus _VI_FUNC rssgu_CALibrationIQModulatorForCurrentFrequencyResult
    (ViSession instrumentHandle, ViInt32* result);
    
  ViStatus _VI_FUNC rssgu_CALibrationGetHostRequest (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar _VI_FAR command[]);

  ViStatus _VI_FUNC rssgu_GetCalibrationIQTemperature (ViSession instrumentHandle,
    ViReal64 *temperature);

  ViStatus _VI_FUNC rssgu_GetCalibrationLevelTemperature (ViSession instrumentHandle,
    ViReal64 *temperature);
    
  ViStatus _VI_FUNC rssgu_GetTraitsCount (ViSession instrumentHandle,
    ViInt32* count);
    
  ViStatus _VI_FUNC rssgu_GetTraits (ViSession instrumentHandle,
    ViInt32 propertyIndex,
    ViInt32 arraySize,
    ViChar _VI_FAR traits[]);


  ViStatus _VI_FUNC rssgu_GetNetworkSystemSettings (ViSession instrumentHandle);
  ViStatus _VI_FUNC rssgu_GetNetworkMACAddress (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar _VI_FAR MACAddress[]);
  ViStatus _VI_FUNC rssgu_ConfigureNetworkIP (ViSession instrumentHandle,
    ViInt32 addressMode, ViString IPAddress,
    ViString subnetMask,
    ViString defaultGateway);

  ViStatus _VI_FUNC rssgu_NetworkRestart (ViSession instrumentHandle);
  ViStatus _VI_FUNC rssgu_GetNetworkResource (ViSession instrumentHandle,
    ViUInt32 arraySize,
    ViChar _VI_FAR resource[]);
  ViStatus _VI_FUNC rssgu_GetNetworkConfigurationState (ViSession instrumentHandle,
    ViBoolean* configuration);
  ViStatus _VI_FUNC rssgu_SetNetworkCommonHostname (ViSession instrumentHandle,
    ViString hostname);
  ViStatus _VI_FUNC rssgu_GetNetworkCommonHostname (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar _VI_FAR hostname[]);
  ViStatus _VI_FUNC rssgu_SetNetworkIPAddressMode (ViSession instrumentHandle,
    ViInt32 addressMode);
  ViStatus _VI_FUNC rssgu_GetNetworkIPAddressMode (ViSession instrumentHandle,
    ViInt32* addressMode);
  ViStatus _VI_FUNC rssgu_SetNetworkIPAddress (ViSession instrumentHandle,
    ViString IPAddress);
  ViStatus _VI_FUNC rssgu_GetNetworkIPAddress (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar _VI_FAR IPAddress[]);
  ViStatus _VI_FUNC rssgu_SetNetworkIPSubnetMask (ViSession instrumentHandle,
    ViString subnetMask);
  ViStatus _VI_FUNC rssgu_GetNetworkIPSubnetMask (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar _VI_FAR subnetMask[]);
  ViStatus _VI_FUNC rssgu_SetNetworkIPDefaultGateway (ViSession instrumentHandle,
    ViString defaultGateway);
  ViStatus _VI_FUNC rssgu_GetNetworkIPDefaultGateway (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar _VI_FAR defaultGateway[]);

  ViStatus _VI_FUNC rssgu_AcceptNetworkIPSettings (ViSession instrumentHandle);

  ViStatus _VI_FUNC rssgu_SetSerialBaudRate (ViSession instrumentHandle,
                                             ViInt32 baudrate);

  ViStatus _VI_FUNC rssgu_GetSerialBaudRate (ViSession instrumentHandle,
                                             ViInt32* baudrate);

  ViStatus _VI_FUNC rssgu_SetSerialParity (ViSession instrumentHandle,
                                           ViInt32 parity);

  ViStatus _VI_FUNC rssgu_GetSerialParity (ViSession instrumentHandle,
    ViInt32* parity);

  ViStatus _VI_FUNC rssgu_SetSerialStopBits (ViSession instrumentHandle,
    ViInt32 stopbits);

  ViStatus _VI_FUNC rssgu_GetSerialStopBits (ViSession instrumentHandle,
    ViInt32* stopbits);


  ViStatus _VI_FUNC rssgu_SetRemoteOperationMode (ViSession instrumentHandle,
    ViInt32 operationMode);
  ViStatus _VI_FUNC rssgu_GetRemoteOperationMode (ViSession instrumentHandle,
    ViInt32* operationMode);



  ViStatus _VI_FUNC rssgu_ClearStatus (ViSession instrumentHandle);
  ViStatus _VI_FUNC rssgu_EventStatusEnable (ViSession instrumentHandle,
    ViInt32 registerValue);
  ViStatus _VI_FUNC rssgu_EventStatusQuery (ViSession instrumentHandle,
    ViInt32* registerValue);
  ViStatus _VI_FUNC rssgu_IdentificationQuery (ViSession instrumentHandle,
    ViChar _VI_FAR instrumentIdentification[]);
  ViStatus _VI_FUNC rssgu_IndividualStatusQuery (ViSession instrumentHandle,
    ViInt32* ISTFlag);
  ViStatus _VI_FUNC rssgu_OperationComplete (ViSession instrumentHandle);
  ViStatus _VI_FUNC rssgu_OperationCompleteQuery (ViSession instrumentHandle,
    ViInt32* OPCState);
  ViStatus _VI_FUNC rssgu_OptionIdentificationQuery (ViSession instrumentHandle,
    ViChar _VI_FAR optionIdentification[]);
  ViStatus _VI_FUNC rssgu_ParallelPollRegisterEnable (ViSession instrumentHandle,
    ViInt32 registerValue);
  ViStatus _VI_FUNC rssgu_ParallelPollRegisterQuery (ViSession instrumentHandle,
    ViInt32* registerValue);
  ViStatus _VI_FUNC rssgu_PowerOnStatusClear (ViSession instrumentHandle,
    ViInt32 registerValue);
  ViStatus _VI_FUNC rssgu_PowerOnStatusClearQuery (ViSession instrumentHandle,
    ViInt32* registerValue);
  ViStatus _VI_FUNC rssgu_Recall (ViSession instrumentHandle,
    ViInt32 instrumentStatus);
  ViStatus _VI_FUNC rssgu_Save (ViSession instrumentHandle, ViInt32 instrumentStatus);
  ViStatus _VI_FUNC rssgu_ServiceRequestEnable (ViSession instrumentHandle,
    ViInt32 registerValue);
  ViStatus _VI_FUNC rssgu_ServiceRequestEnableQuery (ViSession instrumentHandle,
    ViInt32* registerValue);
  ViStatus _VI_FUNC rssgu_StatusByteQuery (ViSession instrumentHandle,
    ViInt32* statusByte);
  ViStatus _VI_FUNC rssgu_Trigger (ViSession instrumentHandle);
  ViStatus _VI_FUNC rssgu_TriggerWaitOPC (ViSession instrumentHandle,
    ViInt32 timeout);
  ViStatus _VI_FUNC rssgu_SetTrigConnnectorOpMode (ViSession instrumentHandle,
    ViInt32 mode);
  ViStatus _VI_FUNC rssgu_GetTrigConnnectorOpMode (ViSession instrumentHandle,
    ViInt32* mode);
  ViStatus _VI_FUNC rssgu_SelfTestQuery (ViSession instrSession,
    ViInt32 *errorCode);
  ViStatus _VI_FUNC rssgu_WaittoContinue (ViSession instrumentHandle);
  ViStatus _VI_FUNC rssgu_DIAGnosticTestPoints (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar _VI_FAR testPoints[]);
  ViStatus _VI_FUNC rssgu_DIAGnosticTestPointVoltage (ViSession instrumentHandle,
    ViString testPointName,
    ViReal64* measuredVoltage);
  ViStatus _VI_FUNC rssgu_DIAGnosticGetMemoryContent (ViSession instrumentHandle,
    ViInt32 bar, ViInt32 adress,
    ViInt32* data);
  ViStatus _VI_FUNC rssgu_DIAGnosticSetMemoryContent (ViSession instrumentHandle,
    ViInt32 bar, ViInt32 adress,
    ViInt32 data);
  ViStatus _VI_FUNC rssgu_MemoryHeapFree (ViSession instrumentHandle,
    ViInt32* TotalPhysMemKb,
    ViInt32* ApplicMemKb,
    ViInt32* HeapUsedKb,
    ViInt32* HeapAvailableKb);


  ViStatus _VI_FUNC rssgu_MMEMoryChangeDefaultDrive (ViSession instrumentHandle,
    ViString drive);
  ViStatus _VI_FUNC rssgu_MMEMoryGetDefaultDrive (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar _VI_FAR drive[]);
  ViStatus _VI_FUNC rssgu_MMEMoryChangeDirectory (ViSession instrumentHandle,
    ViString directoryName);
  ViStatus _VI_FUNC rssgu_MMEMoryGetDirectory (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar _VI_FAR directory[]);
  ViStatus _VI_FUNC rssgu_MMEMoryCopy (ViSession instrumentHandle,
    ViString sourcePath, ViString destinationPath);
  ViStatus _VI_FUNC rssgu_MMEMoryBlockDataWrite (ViSession instrumentHandle,
    ViString fileName,
    ViInt32 binaryBlockLength,
    ViChar _VI_FAR binaryBlockData[]);
  ViStatus _VI_FUNC rssgu_MMEMoryBlockDataRead (ViSession instrumentHandle,
    ViString fileName,
    ViInt32 binaryBlockLength,
    ViChar _VI_FAR binaryBlockData[]);
  ViStatus _VI_FUNC rssgu_MMEMoryCatalog (ViSession instrumentHandle,
    ViString directoryPath, ViInt32 arraySize,
    ViChar _VI_FAR catalogList[]);
  ViStatus _VI_FUNC rssgu_MMEMoryCatalogLength (ViSession instrumentHandle,
    ViString directoryPath,
    ViInt32* length);

  ViStatus _VI_FUNC rssgu_MMEMoryDirectoryCatalog (ViSession instrumentHandle,
    ViString directoryPath,
    ViInt32 arraySize,
    ViChar _VI_FAR catalogList[]);
  ViStatus _VI_FUNC rssgu_MMEMoryDirectoryCatalogLength (ViSession instrumentHandle,
    ViString directoryPath,
    ViInt32* length);

  ViStatus _VI_FUNC rssgu_MMEMoryDelete (ViSession instrumentHandle,
    ViString fileName);
  ViStatus _VI_FUNC rssgu_MMEMoryMakeDirectory (ViSession instrumentHandle,
    ViString directoryName);
  ViStatus _VI_FUNC rssgu_MMEMoryMove (ViSession instrumentHandle,
    ViString fileSource, ViString fileDestination);
  ViStatus _VI_FUNC rssgu_MMEMoryRemoveDirectory (ViSession instrumentHandle,
    ViString directoryName);
  ViStatus _VI_FUNC rssgu_MMEMoryLoadState (ViSession instrumentHandle,
    ViInt32 storage,  
    ViString fileName);

  ViStatus _VI_FUNC rssgu_MMEMoryStoreState (ViSession instrumentHandle,
    ViInt32 storage,  
    ViString fileName);


  ViStatus _VI_FUNC rssgu_TESTSelftestResult (ViSession instrumentHandle,
    ViInt32* result);
  ViStatus _VI_FUNC rssgu_TESTSelftestStart (ViSession instrumentHandle);

  ViStatus _VI_FUNC rssgu_ApplySettings (ViSession instrumentHandle);

  ViStatus _VI_FUNC rssgu_TestSpeed (ViSession instrumentHandle, ViReal64 frequency,
    ViReal64 level);

  ViStatus _VI_FUNC rssgu_SetTestKeyboardState (ViSession instrumentHandle,
    ViBoolean state);

  ViStatus _VI_FUNC rssgu_GetTestKeyboardState (ViSession instrumentHandle,
    ViBoolean *state);

  ViStatus _VI_FUNC rssgu_SetRegister (ViSession instrumentHandle,
    ViInt32 registerGroup, ViInt32 registerType,
    ViInt32 value);
  ViStatus _VI_FUNC rssgu_GetRegister (ViSession instrumentHandle,
    ViInt32 registerGroup, ViInt32 registerType,
    ViInt32* value);
  ViStatus _VI_FUNC rssgu_STATusPRESet (ViSession instrumentHandle);
  ViStatus _VI_FUNC rssgu_SYSTemErrorQueueAll (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar _VI_FAR errorQueue[]);
  ViStatus _VI_FUNC rssgu_SYSTemErrorQueueCodeAll (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar _VI_FAR errorQueueCode[]);
  ViStatus _VI_FUNC rssgu_SYSTemErrorQueueCodeNext (ViSession instrumentHandle,
    ViInt32* errorQueueCodeNext);
  ViStatus _VI_FUNC rssgu_SYSTemErrorQueueCount (ViSession instrumentHandle,
    ViInt32* errorQueueCount);
  ViStatus _VI_FUNC rssgu_SYSTemStaticErrorQueue (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar _VI_FAR errorQueue[]);
  ViStatus _VI_FUNC rssgu_SYSTemUSBResource (ViSession instrumentHandle,
    ViUInt32 arraySize,
    ViChar _VI_FAR USBResource[]);
  ViStatus _VI_FUNC rssgu_SYSTemSocketResource (ViSession instrumentHandle,
    ViUInt32 arraySize,
    ViChar _VI_FAR SocketResource[]);

  ViStatus _VI_FUNC rssgu_SYSTemPCIeResource (ViSession instrumentHandle,
    ViUInt32 arraySize,
    ViChar _VI_FAR PCIeResource[]);

  ViStatus _VI_FUNC rssgu_SYSTemHislipResource (ViSession instrumentHandle,
    ViUInt32 arraySize,
    ViChar _VI_FAR HislipResource[]);

  ViStatus _VI_FUNC rssgu_SYSTemSerialResource (ViSession instrumentHandle,
    ViUInt32 arraySize,
    ViChar _VI_FAR SerialResource[]);

  ViStatus _VI_FUNC rssgu_SYSTemRestoreFactorySettings (ViSession instrumentHandle);

  ViStatus _VI_FUNC rssgu_SetSYSTemEcoMode (ViSession instrumentHandle,
    ViInt32 mode);

  ViStatus _VI_FUNC rssgu_GetSYSTemEcoMode (ViSession instrumentHandle,
    ViInt32 *mode);

  ViStatus _VI_FUNC rssgu_SetSYSTemProtect (ViSession instrumentHandle,
    ViInt32 protectionLevel,
    ViBoolean protection, ViString password);
  ViStatus _VI_FUNC rssgu_GetSYSTemProtect (ViSession instrumentHandle,
    ViInt32 protectionLevel,
    ViBoolean* protection);
  ViStatus _VI_FUNC rssgu_GetSYSTemVersion (ViSession instrumentHandle,
    ViChar _VI_FAR SCPIVersion[]);
  ViStatus _VI_FUNC rssgu_GetSYSTemStartupStatus (ViSession instrumentHandle,
    ViInt32* startupComplete);
  ViStatus _VI_FUNC rssgu_SetSYSTemTerminatorMode (ViSession instrumentHandle,
    ViInt32 mode);
  ViStatus _VI_FUNC rssgu_GetSYSTemTerminatorMode (ViSession instrumentHandle,
    ViInt32* mode);

  ViStatus _VI_FUNC rssgu_GetSYSTemOperatingSystem (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar osname[]);

  ViStatus _VI_FUNC rssgu_GetSYSTemUserMemoryPath (ViSession instrumentHandle,
    ViInt32 arraySize,
    ViChar path[]);


  ViStatus _VI_FUNC rssgu_SetAngleUnits (ViSession instrumentHandle,
    ViInt32 angleUnits);
  ViStatus _VI_FUNC rssgu_GetAngleUnits (ViSession instrumentHandle,
    ViInt32* angleUnits);
  ViStatus _VI_FUNC rssgu_SetPowerUnits (ViSession instrumentHandle,
    ViInt32 powerUnits);
  ViStatus _VI_FUNC rssgu_GetPowerUnits (ViSession instrumentHandle,
    ViInt32* powerUnits);

  ViStatus _VI_FUNC rssgu_SetFormatData (ViSession instrumentHandle, ViInt32 format);
  ViStatus _VI_FUNC rssgu_GetFormatData (ViSession instrumentHandle, ViInt32* format);
  ViStatus _VI_FUNC rssgu_errorCheckState (ViSession instrumentHandle,
    ViBoolean stateChecking);
  ViStatus _VI_FUNC rssgu_optionCheckState (ViSession instrumentHandle,
    ViBoolean stateChecking);
  ViStatus _VI_FUNC rssgu_setCheckRange (ViSession instrumentHandle,
    ViBoolean rangeChecking);
  ViStatus _VI_FUNC rssgu_writeInstrData (ViSession instrumentHandle,
    ViString writeBuffer);
  ViStatus _VI_FUNC rssgu_readInstrData (ViSession instrumentHandle,
    ViInt32 numberBytesToRead,
    ViChar _VI_FAR readBuffer[],
    ViInt32* numBytesRead);
  ViStatus _VI_FUNC rssgu_reset (ViSession instrumentHandle);
  ViStatus _VI_FUNC rssgu_Clear (ViSession instrumentHandle);
  ViStatus _VI_FUNC rssgu_self_test (ViSession instrumentHandle,
    ViInt16* selfTestResult,
    ViChar _VI_FAR selfTestMessage[]);
  ViStatus _VI_FUNC rssgu_error_query (ViSession instrumentHandle, ViInt32* errorCode,
    ViChar _VI_FAR errorMessage[]);
  ViStatus _VI_FUNC rssgu_error_message (ViSession instrumentHandle,
    ViStatus statusCode,
    ViChar _VI_FAR message[]);
  ViStatus _VI_FUNC rssgu_revision_query (ViSession instrumentHandle,
    ViChar _VI_FAR instrumentDriverRevision[],
    ViChar _VI_FAR firmwareRevision[]);
  ViStatus _VI_FUNC rssgu_enumerate_pcie_devices (ViInt32 vendorID, ViInt32 deviceID,
    ViInt32 _VI_FAR serialNumbers[],
    ViInt32* arraySize);
  ViStatus _VI_FUNC rssgu_enumerate_socket_devices (ViPString *info, ViPInt32 infoCount);                                               
  ViStatus _VI_FUNC rssgu_delay (ViSession instrumentHandle, ViReal64 seconds);
  ViStatus _VI_FUNC rssgu_close (ViSession instrumentHandle);
  ViStatus _VI_FUNC rssgu_Restart (ViSession instrumentHandle);
  ViStatus _VI_FUNC rssgu_Standby (ViSession instrumentHandle);


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
