#include <visa.h>

/*= Useful Macros ===========================================================*/

/* - Basic Macros ---------------------------------------------------------- */

/* Error checking macro */
#define CHECKERR(fCal) if (rssgu_status = (fCal), rssgu_status < VI_SUCCESS) \
    return rssgu_status

/* Error checking macro with jump to the ERROR: label */
#define GOCHECKERR(fCal) if (rssgu_status = (fCal), rssgu_status < VI_SUCCESS) \
                            goto ERROR_LABEL
/**#define GOCHECKERR(fCal) if (rssgu_status = (fCal), rssgu_status < VI_SUCCESS) \
                            goto ERROR_LABEL; else
*/
/* Parameter checking macro */
#define CHECKPARAM(fCal,param) if (fCal != VI_SUCCESS) return VI_ERROR_PARAMETER##param

/* Checking path parameter */
#define CHECKPATH if (rssgu_invalidViInt32Range (path, RSSGU_PATH_A, RSSGU_PATH_B)) return VI_ERROR_PARAMETER2;

/* Initialize default function parameters */
#define INIT\
    ViStatus            rssgu_status = VI_SUCCESS; \
    int                 handle = -1;\
    rssgu_instrRange    instrPtr = NULL; \
    CHECKERR (viGetAttribute (instrSession, VI_ATTR_USER_DATA, &handle));\
    instrPtr = rssgu_GetPointer(handle);\
    if (instrPtr == NULL)\
        return VI_ERROR_PARAMETER1

/* Close function and return */
#define RETURN\
    return rssgu_status;

/* - Additional Macros ----------------------------------------------------- */

#define CHECKOPT(option) if (instrPtr->optionChecking == VI_TRUE)\
                         {\
                            if (instrPtr->instrOptions.option == 0)\
                                return RSSGU_ERROR_INSTRUMENT_OPTION;\
                         }

#define CHECKOPTCONT(option) if (instrPtr->optionChecking == VI_TRUE)\
                         {\
                            if (instrPtr->instrOptions.option == 0)\
                                rssgu_status = RSSGU_ERROR_INSTRUMENT_OPTION;\
                         }
/* Remap parameter error code */
#define REMAP(par_in, par_out) if (rssgu_status == VI_ERROR_PARAMETER##par_in)\
                                    rssgu_status = VI_ERROR_PARAMETER##par_out;\
                                if (rssgu_status < VI_SUCCESS)\
                                    return rssgu_status

#define REMAPINSTR(par_in, par_out) if (rssgu_status == VI_ERROR_PARAMETER##par_in)\
                                    rssgu_status = VI_ERROR_INSTR_PARAMETER##par_out;\
                                if (rssgu_status < VI_SUCCESS)\
                                    return rssgu_status

/* Check NULL pointer */
#define CHECKNULL(pointer, param) if (pointer == NULL) return VI_ERROR_PARAMETER##param


/* Supported instruments */

/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT STATUS/RANGE STRUCTURE  ============================*/
/*****************************************************************************/
/* rssgu_stringValPair is used in the rssgu_error_message function           */
/* rssgu_statusDataRanges is used to track session dependent status & ranges */
/*===========================================================================*/
typedef struct  rssgu_stringValPair
{
   ViStatus stringVal;
   ViString stringName;
}  rssgu_tStringValPair;

typedef struct rssgu_instrOptions
{
    int B26:1;
    int B120:1;
    int B120V:1;
    int B140:1;
    int B140V:1;
} rssgu_tinstrOptions;

struct rssgu_statusDataRanges
{
    ViChar              instrDriverRevision[256];
    ViBoolean           errorChecking;
    ViBoolean           optionChecking;
    ViBoolean           rangeChecking;
    ViInt32             instrVer;
    rssgu_tinstrOptions instrOptions;
};

typedef struct rssgu_statusDataRanges *rssgu_instrRange;
ViBoolean rssgu_invalidViBooleanRange (ViSession instrSession, ViBoolean val);
ViBoolean rssgu_invalidViInt32Range (ViSession instrSession, ViInt32 val, ViInt32 min, ViInt32 max);
ViBoolean rssgu_invalidViReal64Range (ViSession instrSession, ViReal64 val, ViReal64 min,
                                       ViReal64 max);
ViStatus rssgu_checkStatus (ViSession instrSession);
ViStatus rssgu_waitOPC (ViSession instrSession, ViPString command,
                        ViPString instrResp, ViInt32 timeout);
ViStatus rssgu_sendCmd (ViSession instrSession, ViString cmd);
ViStatus rssgu_setViInt32 (ViSession instrSession,
                           ViString cmd,
                           ViInt32 value,
                           ViInt32 min,
                           ViInt32 max,
                           ViStatus parameterErrorCode);
ViStatus rssgu_getViInt32 (ViSession instrSession,
                           ViString cmd,
                           ViInt32 *value,
                           ViStatus parameterErrorCode);
ViStatus rssgu_setViBoolean (ViSession instrSession,
                           ViString cmd,
                           ViBoolean value,
                           ViStatus parameterErrorCode);
ViStatus rssgu_getViBoolean (ViSession instrSession,
                           ViString cmd,
                           ViBoolean *value,
                           ViStatus parameterErrorCode);
ViStatus rssgu_setViReal64 (ViSession vi,
                            ViString cmd,
                            ViReal64 value,
                            ViReal64 min,
                            ViReal64 max,
                            ViStatus parameterErrorCode);
ViStatus rssgu_getViReal64 (ViSession instrSession,
                            ViString cmd,
                            ViReal64 *value,
                            ViStatus parameterErrorCode);
ViStatus rssgu_setViReal64Units (ViSession instrSession,
                                 ViString cmd,
                                 ViReal64 value,
                                 ViString units,
                                 ViReal64 min,
                                 ViReal64 max,
                                 ViStatus parameterErrorCode);
ViStatus rssgu_setViString (ViSession instrSession,
                            ViString cmd,
                            ViString value,
                            ViStatus parameterErrorValue);
ViStatus rssgu_getViString (ViSession instrSession,
                            ViString cmd,
                            ViString value,
                            ViUInt32 buffer_size,
                            ViStatus parameterErrorCode);
ViStatus rssgu_setViStringQuoted (ViSession instrSession,
                            ViString cmd,
                            ViString quotes,
                            ViString value,
                            ViStatus parameterErrorValue);
ViStatus rssgu_setEnum (ViSession instrSession,
                        ViString cmd,
                        ViInt32 value,
                        ViString list[],
                        ViStatus parameterErrorCode);
ViStatus rssgu_getEnum (ViSession instrSession,
                        ViString cmd,
                        ViInt32 *value,
                        ViString list[],
                        ViStatus parameterErrorCode);
ViStatus rssgu_checkIndexInList (ViInt32 index,
                                 ViString list[],
                                 ViStatus statusIfError);
ViStatus rssgu_getIndexFromString (ViString string,
                                   ViString *list,
                                   ViInt32 *index);
ViStatus rssgu_getCatalog (ViSession instrSession,
                           ViString cmd,
                           ViUInt32 arraySize,
                           ViChar* array,
                           ViInt32 parameterErrorCode);
ViStatus rssgu_getViReal64Array (ViSession instrSession,
                            ViString cmd,
                            ViReal64 *value,
                            ViInt32  count,
                            ViStatus parameterErrorCode);
ViStatus rssgu_getViInt32Array (ViSession instrSession,
                            ViString cmd,
                            ViInt32 *value,
                            ViInt32  count,
                            ViStatus parameterErrorCode);
ViStatus rssgu_readDataUnknownLength(ViSession instrSession,
                                     /*@null@*/ViChar **outBuffer,
                                     ViUInt32 *count);
ViStatus rssgu_getViUInt32 (ViSession instrSession,
                           ViString cmd,
                           ViUInt32 *value,
                           ViStatus parameterErrorCode);
ViStatus rssgu_getViStringQuoted (ViSession instrSession,
                                  ViString cmd,
                                  ViString quotes,
                                  ViInt32  arraySize,
                                  ViChar   value[],
                                  ViStatus parameterErrorValue);
void rssgu_SWAP_32(unsigned char *data, long points);
ViStatus _VI_FUNC rssgu_ReadTraceData(
    ViSession   instrSession,
    ViString    cmd,
    ViInt32*    noofPoints,
    ViReal64    _VI_FAR traceData[]
);
ViStatus rssgu_checkBeforeRead (ViSession instrSession);
ViStatus rssgu_readDataToFile (ViSession instrSession, ViString cmd,
                           ViString destination);
ViStatus rssgu_checkInstrument (ViSession instrSession, ViInt32 instrument, ViBoolean generateErrorIfPresent);


unsigned int rssgu_AddPointer(void* pPtr);
void rssgu_RemovePointer(unsigned int handle);
void* rssgu_GetPointer(unsigned int handle);

ViInt32 rssgu_StringIndex(ViString array[], ViChar buff[]);

ViStatus rssgu_getViBooleanArray (ViSession instrSession,
                            ViString cmd,
                            ViBoolean *value,
                            ViInt32  count,
							ViInt32  *returnedValues,
                            ViStatus parameterErrorCode);

